
library("deSolve")
library("bbmle")
setwd(/path/to/your/folder/) ## please replace this according to your path and system
source("source/infection.models.r")
source("source/infection.nll.r")
sample.data = read.csv("data/sample.data.csv")

str(sample.data)

data.control = subset(sample.data, treatment == "control")
data.treat = subset(sample.data, treatment == "treatment")

par(mfrow=c(1,2))
plot(data.control$time.days,
	data.control$number.infected,
	ylim=c(0,10),
	xlab="days",
	ylab="infections control")
plot(data.treat$time.days,
	data.treat$number.infected,
	ylim=c(0,10),
	xlab="days",
	ylab="infections treatment")

fit.treatment.wrong = mle2(minuslogl = mon.inf.lag.1p.nll,
	start = list(r = 1, t0 = 1),
	data = list(nI = data.treat$number.infected,
		tps = data.treat$time.days
	),
	fixed = list(Imax = 10)
)

summary(fit.treatment.wrong)

fit.control = mle2(mon.inf.lag.1p.nll,
	start = list(r = 0.5, t0 = 0.5),
	data = list(nI = data.control$number.infected,
		tps =  data.control$time.days
	),
	fixed = list(Imax = 10)
)
summary(fit.control)


fit.treatment = mle2(mon.inf.lag.2p.nll,
	start = list(rp = 0.5, t0p = 5),
	data = list(nI = data.treat$number.infected,
		tps = data.treat$time.days
	),
	fixed = list(Imax = 10,
		rc = coef(fit.control)[[1]],
		t0c = coef(fit.control)[[2]]
	)
)
summary(fit.treatment)


xvalues = seq(0,20,length=100)

control.est =  data.frame(lsoda(y = c(I = 0),
		times = xvalues,
		func = mon.inf.lag.1p,
		parms = c(r = coef(fit.control)[[1]],
			t0 = coef(fit.control)[[2]],
			Imax = 10)
	)
)

treat.est =  data.frame(lsoda(y = c(Ip = 0, Ic = 0),
		times = xvalues,
		func = mon.inf.lag.2p,
		parms = c(rp = coef(fit.treatment)[[1]],
			t0p = coef(fit.treatment)[[2]],
			rc = coef(fit.treatment)[[3]],
			t0c = coef(fit.treatment)[[4]],
			Imax = 10
		)
	)
)


par(mfrow=c(1,2))
plot(data.control$time.days,
	data.control$number.infected,
	xlim=c(0,20),
	ylim=c(0,10),
	xlab="days",
	ylab="infections")
mtext(side=3,"(a)",line=-1.5,adj=0.03)
lines(control.est$time, control.est$I)

plot(data.treat$time.days,
	data.treat$number.infected,
	xlim=c(0,20),
	ylim=c(0,10),
	xlab="days",
	ylab="infections")
mtext(side=3,"(b)",line=-1.5,adj=0.03)
lines(treat.est$time, treat.est$Ip+treat.est$Ic)

############################################################

fit.control.warning = mle2(mon.inf.lag.1p.nll,
	start = list(r = 3, t0 = 0.5),
	data = list(nI = data.control$number.infected,
		tps =  data.control$time.days
	),
	fixed = list(Imax = 10)
)
summary(fit.control.warning)

fit.control.tracing = mle2(mon.inf.lag.1p.nll,
	start = list(r = 3, t0 = 0.5),
	data = list(nI = data.control$number.infected,
		tps =  data.control$time.days
	),
	fixed = list(Imax = 10, tracing = 1)
)
summary(fit.control.tracing)

fit.control.steps = mle2(mon.inf.lag.1p.nll,
	start = list(r = 3, t0 = 0.5),
	data = list(nI = data.control$number.infected,
		tps =  data.control$time.days
	),
	fixed = list(Imax = 10, steps = 0.01)
)
summary(fit.control.steps)
